<?php

namespace Drupal\layout_builder_bgcolor\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;

/**
 * Provides a class for custom and core Layout plugins.
 */
class LayoutBase extends LayoutDefault {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'background_color' => 'none',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    $default = $this->configuration['background_color'];
    if (!is_string($default)) {
      $default = 'none';
    }
    $form['background_color'] = [
      '#type' => 'select',
      '#options' => [
        'none' => $this->t('None'),
        '#363434' => $this->t('Dark (#363434)'),
        '#faf8f7' => $this->t('Light (#faf8f7)'),
        '#97764c' => $this->t('Primary (#97764c)'),
        '#ad9373' => $this->t('Primary transparent (#AD9373)'),
        '#c7c9cb' => $this->t('Gray transparent (#C7C9CB)'),
        '#ebe6dd' => $this->t('Primary light (#ebe6dd)'),
        '#777777' => $this->t('Menu (#777777)'),
        '#f1f1f2' => $this->t('Light gray (#f1f1f2)'),
      ],
      '#title' => $this->t('Background color'),
      '#description' => $this->t('Choose a background color from the list.'),
      '#default_value' => $default,
      '#empty_value' => 'none',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['background_color'] = $form_state->getValue('background_color');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);

    $background_color = $this->configuration['background_color'] ?? NULL;
    if (!empty($background_color) && $background_color !== 'none') {
      $build['#attributes']['style'] = 'background-color: ' . $background_color;
    }

    return $build;
  }

}
